fnss.topologies.topology.Topology.nbunch_iter — FNSS 0.7.0 documentation

# fnss.topologies.topology.Topology.nbunch_iter

`Topology.` `nbunch_iter`(nbunch=None)

  Return an iterator of nodes contained in nbunch that are also in the graph.

  The nodes in nbunch are checked for membership in the graph and if not are silently ignored.

  Parameters: | nbunch : iterable container, optional (default=all nodes) A container of nodes. The container will be iterated through once.
  Returns: | niter : iterator An iterator over nodes in nbunch that are also in the graph. If nbunch is None, iterate over all nodes in the graph.
  Raises: | NetworkXError If nbunch is not a node or or sequence of nodes. If a node in nbunch is not hashable.

  See also

  `Graph.__iter__`

  Notes

  When nbunch is an iterator, the returned iterator yields values directly from nbunch, becoming exhausted when nbunch is exhausted.

  To test whether nbunch is a single node, one can use “if nbunch in self:”, even after processing with this routine.

  If nbunch is not a node or a (possibly empty) sequence/iterator or None, a NetworkXError is raised. Also, if any object in nbunch is not hashable, a NetworkXError is raised.